import os
from pathlib import Path

from PyQt5.QtGui import QGuiApplication
from PyQt5.QtWidgets import QDialog, QGridLayout, QComboBox, QSizePolicy, QPushButton


class SelectUserWindow(QDialog):
    def __init__(self, drive: Path, parent=None):
        super(SelectUserWindow, self).__init__(parent)
        self.drive = drive

        self.setGeometry(0, 0, 256, 128)
        self.center()
        self.setWindowTitle('Select User')

        self.user_list = self.get_user_list(drive)

        self.selecting_layout = QGridLayout()

        self.selecting_field = QComboBox()
        self.selecting_field.addItems(self.user_list)
        self.selecting_field.setSizePolicy(QSizePolicy.Expanding,
                                           QSizePolicy.Preferred)
        self.selecting_layout.addWidget(self.selecting_field)

        self.selecting_button = QPushButton('Ok')
        self.selecting_button.clicked.connect(self.accept)
        self.selecting_button.setSizePolicy(QSizePolicy.Expanding,
                                            QSizePolicy.Preferred)
        self.selecting_layout.addWidget(self.selecting_button)

        self.setLayout(self.selecting_layout)

    @staticmethod
    def get_user_list(drive):
        user_list = sorted(os.listdir(drive / 'data' / 'user'))
        return user_list

    def center(self):
        qr = self.frameGeometry()
        cp = QGuiApplication.primaryScreen().geometry().center()
        qr.moveCenter(cp)
        self.move(qr.topLeft())

    def get_user(self):
        user_id = self.selecting_field.currentIndex()
        user = self.user_list[user_id]
        return user

    @staticmethod
    def start(drive, parent=None):
        selecting = SelectUserWindow(drive=drive, parent=parent)
        exit_sel = selecting.exec_()
        user = selecting.get_user()
        return user, exit_sel == QDialog.Accepted



{
# FILES
'autoLoad': True,
'standardModelFile':       os.path.dirname(os.path.abspath(path))+'/../../../data/model/model.npy',
'standardSketchFile':      os.path.dirname(os.path.abspath(path))+'/../../../data/sketch/rouse.npy',
'standardRecordingFolder': os.path.dirname(os.path.abspath(path))+'/../../../data/ccv/M220217_DW03',
'standardRecordingFileNames': list([
                                    'cam01VI_20220217_3.ccv',
                                    'cam02VI_20220217_3.ccv',
                                    'cam03VI_20220217_3.ccv',
                                    'cam04VI_20220217_3.ccv',
                                   ]),
#
'standardCalibrationFile': '',
'standardOriginCoordFile': '',
'standardLabelsFile': '',
'invert_xaxis': True,
'invert_yaxis': False,
# GENERAL
'cam': int(0),
'minPose': int(70200),
'maxPose': int(80000),
'dFrame': int(200),
# mode activation
'button_fastLabelingMode_activate': True,
'button_centricViewMode_activate': False,
'button_reprojectionMode_activate': False,
'button_sketchMode_activate': True,
# save settings
'exitSaveModel': False,
'exitSaveLabels': True,
'autoSave': True,
'autoSaveN0': int(10),
'autoSaveN1': int(100),
# BUTTONS
# general
'button_loadRecording': False,
'button_loadModel': False,
'button_loadLabels': False,
'button_loadCalibration': False,
'button_saveModel': False,
'button_saveLabels': True,
'button_loadOrigin': False,
'button_loadSketch': False,
'button_sketchMode': False,
'button_fastLabelingMode': False,
'button_centricViewMode': False,
'button_reprojectionMode': False,
# labels
'button_insert': False,
'button_remove': False,
'button_label3d': False,
'button_previousLabel': True,
'button_nextLabel': True,
# 3d
'button_up': False,
'button_right': False,
'button_down': False,
'button_left': False,
# 2d
'button_next': True,
'button_previous': True,
# 3d and 2d
'button_home': True,
'button_zoom': True,
'button_pan': True,
# FIELDS
'field_dx': False,
'field_dy': False,
'field_vmin': True,
'field_vmax': True,
'field_labels3d': False,
'field_dxyz': False,
'field_currentPose': False,
'field_dFrame': False,
# LISTS
'list_fastLabelingMode': True
}
